@@ -1,4 +1,4 @@
-/*	$NetBSD: subr.c,v 1.5 1997/10/11 01:53:36 lukem Exp $	*/
+/*	$NetBSD: subr.c,v 1.8 1998/09/14 09:29:08 hubertf Exp $	*/
 
 /*-
  * Copyright (c) 1991, 1993
@@ -43,7 +43,7 @@
 #if 0
 static char sccsid[] = "@(#)subr.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: subr.c,v 1.5 1997/10/11 01:53:36 lukem Exp $");
+__RCSID("$NetBSD: subr.c,v 1.8 1998/09/14 09:29:08 hubertf Exp $");
 #endif
 #endif				/* not lint */
 
@@ -92,8 +92,7 @@ liq2(pbotl)
 }
 
 int
-liq(foo)
-	int foo __attribute__((unused));
+liq()
 {
 	int     i;
 	i = prop[bottle];
@@ -134,8 +133,7 @@ forced(locc)
 }
 
 int
-dark(foo)
-	int foo __attribute__((unused));
+dark()
 {
 	if ((cond[loc] % 2) == 0 && (prop[lamp] == 0 || !here(lamp)))
 		return (TRUE);
@@ -476,7 +474,7 @@ trbridge()
 }
 
 
-int
+void
 badmove()
 {				/* 20                   */
 	spk = 12;
@@ -495,19 +493,18 @@ badmove()
 	if (k == 17)
 		spk = 80;
 	rspeak(spk);
-	return (2);
 }
 
-int
+void
 bug(n)
 	int     n;
 {
 	printf("Please tell jim@rand.org that fatal bug %d happened.\n", n);
-	exit(0);
+	exit(1);
 }
 
 
-int
+void
 checkhints()
 {				/* 2600 &c              */
 	int     hint;
@@ -554,7 +551,6 @@ l40010:	hintlc[hint] = 0;
 		hinted[hint] = yes(175, hints[hint][4], 54);
 l40020:	hintlc[hint] = 0;
 	}
-	return 0;
 }
 
 
@@ -590,7 +586,7 @@ trtake()
 	if (fixed[obj] != 0)
 		return (2011);
 	if (obj == water || obj == oil) {
-		if (here(bottle) && liq(0) == obj) {
+		if (here(bottle) && liq() == obj) {
 			obj = bottle;
 			goto l9017;
 		}
@@ -623,7 +619,7 @@ l9017:	if (holdng >= 7) {
 l9014:	if ((obj == bird || obj == cage) && prop[bird] != 0)
 		carry(bird + cage - obj, loc);
 	carry(obj, loc);
-	k = liq(0);
+	k = liq();
 	if (obj == bottle && k != 0)
 		place[k] = -1;
 	return (2009);
@@ -633,7 +629,7 @@ l9014:	if ((obj == bird || obj == cage) && prop[bird] != 0)
 int
 dropper()
 {				/* 9021                 */
-	k = liq(0);
+	k = liq();
 	if (k == obj)
 		obj = bottle;
 	if (obj == bottle && k != 0)
@@ -989,12 +985,12 @@ trfill()
 	spk = 107;
 	if (liqloc(loc) == 0)
 		spk = 106;
-	if (liq(0) != 0)
+	if (liq() != 0)
 		spk = 105;
 	if (spk != 107)
 		return (2011);
 	prop[bottle] = ((cond[loc] % 4) / 2) * 2;
-	k = liq(0);
+	k = liq();
 	if (toting(bottle))
 		place[k] = -1;
 	if (k == oil)
@@ -1003,7 +999,7 @@ trfill()
 }
 
 
-int
+void
 closing()
 {				/* 10000 */
 	int     i;
@@ -1027,11 +1023,10 @@ closing()
 	rspeak(129);
 	clock1 = -1;
 	closng = TRUE;
-	return (19999);
 }
 
 
-int
+void
 caveclose()
 {				/* 11000 */
 	int     i;
@@ -1060,5 +1055,4 @@ caveclose()
 			dstroy(i);
 	rspeak(132);
 	closed = TRUE;
-	return (2);
 }
