@@ -1,4 +1,4 @@
-/*	$NetBSD: input.c,v 1.6 1997/10/10 02:07:18 lukem Exp $	*/
+/*	$NetBSD: input.c,v 1.10 1998/09/13 15:20:31 hubertf Exp $	*/
 
 /*-
  * Copyright (c) 1990, 1993
@@ -50,7 +50,7 @@
 #if 0
 static char sccsid[] = "@(#)input.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: input.c,v 1.6 1997/10/10 02:07:18 lukem Exp $");
+__RCSID("$NetBSD: input.c,v 1.10 1998/09/13 15:20:31 hubertf Exp $");
 #endif
 #endif not lint
 
@@ -61,9 +61,6 @@ __RCSID("$NetBSD: input.c,v 1.6 1997/10/10 02:07:18 lukem Exp $");
 #define MAXDEPTH	15
 
 #define RETTOKEN	'\n'
-#ifdef SYSV
-#define CRTOKEN		'\r'
-#endif
 #define REDRAWTOKEN	'\014'	/* CTRL(L) */
 #define	SHELLTOKEN	'!'
 #define HELPTOKEN	'?'
@@ -73,8 +70,8 @@ __RCSID("$NetBSD: input.c,v 1.6 1997/10/10 02:07:18 lukem Exp $");
 typedef struct {
 	int	token;
 	int	to_state;
-	char	*str;
-	char	*(*func) __P((char));
+	const char	*str;
+	const char	*(*func) __P((char));
 } RULE;
 
 typedef struct {
@@ -103,9 +100,6 @@ typedef struct {
 
 RULE	state0[] = {	{ ALPHATOKEN,	1,	"%c:",		setplane},
 			{ RETTOKEN,	-1,	"",		NULL	},
-#ifdef SYSV
-			{ CRTOKEN,	-1,	"",		NULL	},
-#endif
 			{ HELPTOKEN,	12,	" [a-z]<ret>",	NULL	}},
 	state1[] = {	{ 't',		2,	" turn",	turn	},	
 			{ 'a',		3,	" altitude:",	NULL	},	
@@ -137,9 +131,6 @@ RULE	state0[] = {	{ ALPHATOKEN,	1,	"%c:",		setplane},
 	state4[] = {	{ '@',		9,	" at",		NULL	},	
 			{ 'a',		9,	" at",		NULL	},	
 			{ RETTOKEN,	-1,	"",		NULL	},
-#ifdef SYSV
-			{ CRTOKEN,	-1,	"",		NULL	},
-#endif
 			{ HELPTOKEN,	12,	" @a<ret>",	NULL	}},
 	state5[] = {	{ NUMTOKEN,	7,	"%c",		delayb	},
 			{ HELPTOKEN,	12,	" [0-9]",	NULL	}},
@@ -154,14 +145,8 @@ RULE	state0[] = {	{ ALPHATOKEN,	1,	"%c:",		setplane},
 			{ 'a',		4,	" 270",		rel_dir	},
 			{ 'q',		4,	" 315",		rel_dir	},
 			{ RETTOKEN,	-1,	"",		NULL	},	
-#ifdef SYSV
-			{ CRTOKEN,	-1,	"",		NULL	},	
-#endif
 			{ HELPTOKEN,	12,	" @a<dir><ret>",NULL	}},
 	state7[] = {	{ RETTOKEN,	-1,	"",		NULL	},
-#ifdef SYSV
-	            	{ CRTOKEN,	-1,	"",		NULL	},
-#endif
 			{ HELPTOKEN,	12,	" <ret>",	NULL	}},
 	state8[] = {	{ NUMTOKEN,	4,	"%c",		benum	},
 			{ HELPTOKEN,	12,	" [0-9]",	NULL	}},
@@ -248,7 +233,7 @@ int
 getcommand()
 {
 	int	c, i, done;
-	char	*s, *(*func) __P((char));
+	const char	*s, *(*func) __P((char));
 	PLANE	*pp;
 
 	rezero();
@@ -331,7 +316,6 @@ gettoken()
 			{
 				char *shell, *base;
 
-				setuid(getuid()); /* turn off setuid bit */
 				done_screen();
 
 						 /* run user's favorite shell */
@@ -374,7 +358,7 @@ gettoken()
 		return (tval);
 }
 
-char	*
+const char	*
 setplane(c)
 	char c;
 {
@@ -388,7 +372,7 @@ setplane(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 turn(c)
 	char c;
 {
@@ -397,7 +381,7 @@ turn(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 circle(c)
 	char c;
 {
@@ -407,7 +391,7 @@ circle(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 left(c)
 	char c;
 {
@@ -418,18 +402,18 @@ left(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 right(c)
 	char c;
 {
 	dir = D_RIGHT;
 	p.new_dir = p.dir + 1;
-	if (p.new_dir > MAXDIR)
+	if (p.new_dir >= MAXDIR)
 		p.new_dir -= MAXDIR;
 	return (NULL);
 }
 
-char	*
+const char	*
 Left(c)
 	char c;
 {
@@ -439,17 +423,17 @@ Left(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 Right(c)
 	char c;
 {
 	p.new_dir = p.dir + 2;
-	if (p.new_dir > MAXDIR)
+	if (p.new_dir >= MAXDIR)
 		p.new_dir -= MAXDIR;
 	return (NULL);
 }
 
-char	*
+const char	*
 delayb(ch)
 	char ch;
 {
@@ -460,9 +444,9 @@ delayb(ch)
 
 	if (c >= sp->num_beacons)
 		return ("Unknown beacon");
-	xdiff = sp->beacon[c].x - p.xpos;
+	xdiff = sp->beacon[(int)c].x - p.xpos;
 	xdiff = SGN(xdiff);
-	ydiff = sp->beacon[c].y - p.ypos;
+	ydiff = sp->beacon[(int)c].y - p.ypos;
 	ydiff = SGN(ydiff);
 	if (xdiff != displacement[p.dir].dx || ydiff != displacement[p.dir].dy)
 		return ("Beacon is not in flight path");
@@ -472,16 +456,16 @@ delayb(ch)
 	if (dest_type != T_NODEST) {
 		switch (dest_type) {
 		case T_BEACON:
-			xdiff = sp->beacon[dest_no].x - sp->beacon[c].x;
-			ydiff = sp->beacon[dest_no].y - sp->beacon[c].y;
+			xdiff = sp->beacon[dest_no].x - sp->beacon[(int)c].x;
+			ydiff = sp->beacon[dest_no].y - sp->beacon[(int)c].y;
 			break;
 		case T_EXIT:
-			xdiff = sp->exit[dest_no].x - sp->beacon[c].x;
-			ydiff = sp->exit[dest_no].y - sp->beacon[c].y;
+			xdiff = sp->exit[dest_no].x - sp->beacon[(int)c].x;
+			ydiff = sp->exit[dest_no].y - sp->beacon[(int)c].y;
 			break;
 		case T_AIRPORT:
-			xdiff = sp->airport[dest_no].x - sp->beacon[c].x;
-			ydiff = sp->airport[dest_no].y - sp->beacon[c].y;
+			xdiff = sp->airport[dest_no].x - sp->beacon[(int)c].x;
+			ydiff = sp->airport[dest_no].y - sp->beacon[(int)c].y;
 			break;
 		default:
 			return ("Bad case in delayb!  Get help!");
@@ -496,7 +480,7 @@ delayb(ch)
 	return (NULL);
 }
 
-char	*
+const char	*
 beacon(c)
 	char c;
 {
@@ -504,7 +488,7 @@ beacon(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 ex_it(c)
 	char c;
 {
@@ -512,7 +496,7 @@ ex_it(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 airport(c)
 	char c;
 {
@@ -520,7 +504,7 @@ airport(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 climb(c)
 	char c;
 {
@@ -528,7 +512,7 @@ climb(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 descend(c)
 	char c;
 {
@@ -536,7 +520,7 @@ descend(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 setalt(c)
 	char c;
 {
@@ -546,7 +530,7 @@ setalt(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 setrelalt(c)
 	char c;
 {
@@ -571,7 +555,7 @@ setrelalt(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 benum(ch)
 	char ch;
 {
@@ -583,20 +567,20 @@ benum(ch)
 	case T_BEACON:
 		if (c >= sp->num_beacons)
 			return ("Unknown beacon");
-		p.new_dir = DIR_FROM_DXDY(sp->beacon[c].x - p.xpos,
-			sp->beacon[c].y - p.ypos);
+		p.new_dir = DIR_FROM_DXDY(sp->beacon[(int)c].x - p.xpos,
+			sp->beacon[(int)c].y - p.ypos);
 		break;
 	case T_EXIT:
 		if (c >= sp->num_exits)
 			return ("Unknown exit");
-		p.new_dir = DIR_FROM_DXDY(sp->exit[c].x - p.xpos,
-			sp->exit[c].y - p.ypos);
+		p.new_dir = DIR_FROM_DXDY(sp->exit[(int)c].x - p.xpos,
+			sp->exit[(int)c].y - p.ypos);
 		break;
 	case T_AIRPORT:
 		if (c >= sp->num_airports)
 			return ("Unknown airport");
-		p.new_dir = DIR_FROM_DXDY(sp->airport[c].x - p.xpos,
-			sp->airport[c].y - p.ypos);
+		p.new_dir = DIR_FROM_DXDY(sp->airport[(int)c].x - p.xpos,
+			sp->airport[(int)c].y - p.ypos);
 		break;
 	default:
 		return ("Unknown case in benum!  Get help!");
@@ -605,7 +589,7 @@ benum(ch)
 	return (NULL);
 }
 
-char	*
+const char	*
 to_dir(c)
 	char c;
 {
@@ -613,7 +597,7 @@ to_dir(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 rel_dir(c)
 	char c;
 {
@@ -638,7 +622,7 @@ rel_dir(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 mark(c)
 	char c;
 {
@@ -650,7 +634,7 @@ mark(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 unmark(c)
 	char c;
 {
@@ -662,7 +646,7 @@ unmark(c)
 	return (NULL);
 }
 
-char	*
+const char	*
 ignore(c)
 	char c;
 {
