@@ -1,4 +1,4 @@
-/*	$NetBSD: fancy.c,v 1.6 1997/10/14 00:41:20 lukem Exp $	*/
+/*	$NetBSD: fancy.c,v 1.7 1998/09/13 15:19:35 hubertf Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)fancy.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: fancy.c,v 1.6 1997/10/14 00:41:20 lukem Exp $");
+__RCSID("$NetBSD: fancy.c,v 1.7 1998/09/13 15:19:35 hubertf Exp $");
 #endif
 #endif /* not lint */
 
@@ -585,13 +585,6 @@ clear()
 	tputs(CL, CO, addbuf);	/* put CL in buffer */
 }
 
-void
-tos()
-{				/* home cursor */
-	curmove(0, 0);
-}
-
-
 void
 fancyc(c)
 	char    c;		/* character to output */
@@ -698,7 +691,7 @@ newline()
 
 int
 getcaps(s)
-	char   *s;
+	const char   *s;
 {
 	char   *code;		/* two letter code */
 	char ***cap;		/* pointer to cap string */
@@ -740,5 +733,9 @@ getcaps(s)
 	if (LI < 24 || CO < 72 || !(CL && UP && ND))
 		return (0);
 	linect = (int *) calloc(LI + 1, sizeof(int));
+	if (linect == NULL) {
+		write(2, "\r\nOut of memory!\r\n", 18);
+		getout(0);
+	}
 	return (1);
 }
