@@ -1,4 +1,4 @@
-/*	$NetBSD: cypher.c,v 1.6 1997/10/11 02:07:11 lukem Exp $	*/
+/*	$NetBSD: cypher.c,v 1.7 1998/08/24 00:25:32 hubertf Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)cypher.c	8.2 (Berkeley) 4/28/95";
 #else
-__RCSID("$NetBSD: cypher.c,v 1.6 1997/10/11 02:07:11 lukem Exp $");
+__RCSID("$NetBSD: cypher.c,v 1.7 1998/08/24 00:25:32 hubertf Exp $");
 #endif
 #endif				/* not lint */
 
@@ -51,7 +51,8 @@ cypher()
 	int     junk;
 	int     lflag = -1;
 	char    buffer[10];
-	char	filename[1024];
+	char   *filename;
+	size_t	filename_len;
 
 	while (wordtype[wordnumber] == ADJS)
 		wordnumber++;
@@ -119,9 +120,36 @@ cypher()
 				for (n = 0; n < NUMOFOBJECTS; n++)
 					if (testbit(location[position].objects, n) && objsht[n]) {
 						wordvalue[wordnumber + 1] = n;
-						wordtype[wordnumber + 1] = OBJECT;
-						if ((n == AMULET) || (n == MEDALION) || (n == TALISMAN) || (n == MAN) || (n == TIMER) || (n == NATIVE))
+						/* Some objects (type NOUNS)
+						 * have special treatment in
+						 * take().  For these we
+						 * must set the type to NOUNS.
+						 * However for SWORD and BODY
+						 * all it does is find which
+						 * of many objects is meant,
+						 * so we need do nothing here.
+						 * BATHGOD must become
+						 * NORMGOD as well.  NOUNS
+						 * with no special case
+						 * must be included here to
+						 * get the right error.  DOOR
+						 * cannot occur as an object
+						 * so need not be included.  */
+						switch(n) {
+						case BATHGOD:
+							wordvalue[wordnumber + 1] = NORMGOD;
+						case NORMGOD:
+						case AMULET:
+						case MEDALION:
+						case TALISMAN:
+						case MAN:
+						case TIMER:
+						case NATIVE:
 							wordtype[wordnumber + 1] = NOUNS;
+							break;
+						default:
+							wordtype[wordnumber + 1] = OBJECT;
+						}
 						wordnumber = take(location[position].objects);
 					}
 				wordnumber++;
@@ -341,13 +369,17 @@ cypher()
 			break;
 
 		case SAVE:
-			printf("\nSave file name (default .Bstar) ");
-			fgets(filename, sizeof(filename), stdin);
-			if (filename[0] == '\n' || filename[0] == 0)
-				save(".Bstar");
+			printf("\nSave file name (default %s) ",
+			       DEFAULT_SAVE_FILE);
+			filename = fgetln(stdin, &filename_len);
+			if (filename_len == 0
+			    || (filename_len == 1 && filename[0] == '\n'))
+				save(DEFAULT_SAVE_FILE,
+				     strlen(DEFAULT_SAVE_FILE));
 			else {
-				filename[strlen(filename) - 1] = 0;
-				save(filename);
+				if (filename[filename_len - 1] == '\n')
+					filename_len--;
+				save(filename, filename_len);
 			}
 			break;
 
