@@ -1,4 +1,4 @@
-/*	$NetBSD: extern.h,v 1.7 1998/02/03 05:39:25 perry Exp $ */
+/*	$NetBSD: extern.h,v 1.9 1998/09/13 15:27:26 hubertf Exp $ */
 
 /*
  * Copyright (c) 1983, 1993
@@ -223,7 +223,7 @@
 #define MAXCUMBER	10
 
 struct room {
-	char   *name;
+	const char   *name;
 	int     link[8];
 #define north	link[0]
 #define south	link[1]
@@ -233,7 +233,7 @@ struct room {
 #define access	link[5]
 #define down	link[6]
 #define flyhere	link[7]
-	char   *desc;
+	const char   *desc;
 	unsigned int objects[NUMOFWORDS];
 };
 extern struct room dayfile[];
@@ -241,11 +241,11 @@ extern struct room nightfile[];
 struct room *location;
 
  /* object characteristics */
-extern char   *objdes[NUMOFOBJECTS];
-extern char   *objsht[NUMOFOBJECTS];
-extern char   *ouch[NUMOFINJURIES];
-extern int     objwt[NUMOFOBJECTS];
-extern int     objcumber[NUMOFOBJECTS];
+extern const char   *const objdes[NUMOFOBJECTS];
+extern const char   *const objsht[NUMOFOBJECTS];
+extern const char   *const ouch[NUMOFINJURIES];
+extern const int     objwt[NUMOFOBJECTS];
+extern const int     objcumber[NUMOFOBJECTS];
 
  /* current input line */
 #define NWORD	20		/* words per line */
@@ -284,10 +284,10 @@ unsigned int wear[NUMOFWORDS];
 char    beenthere[NUMOFROOMS + 1];
 char    injuries[NUMOFINJURIES];
 
-char    uname[9];
+char    username[9];
 
 struct wlist {
-	char   *string;
+	const char   *string;
 	int     value, article;
 	struct wlist *next;
 };
@@ -301,39 +301,41 @@ struct objs {
 	short   room;
 	short   obj;
 };
-extern struct objs dayobjs[];
-extern struct objs nightobjs[];
+extern const struct objs dayobjs[];
+extern const struct objs nightobjs[];
+
+#define DEFAULT_SAVE_FILE	".Bstar"
 
 void blast __P((void));
 void bury __P((void));
-int card __P((char *, int));
-int checkout __P((char *));
+int card __P((const char *, int));
+int checkout __P((const char *));
 void chime __P((void));
 void convert __P((int));
 void crash __P((void));
 int cypher __P((void));
-void die __P((void));
-void diesig __P((int));
+void die __P((void)) __attribute__((__noreturn__));
+void diesig __P((int)) __attribute__((__noreturn__));
 void dig __P((void));
 int draw __P((void));
 void drink __P((void));
 int drive __P((void));
-int drop __P((char *));
+int drop __P((const char *));
 int eat __P((void));
 void endfly __P((void));
 int fight __P((int, int));
 int follow __P((void));
 void getutmp __P((char *));
 int give __P((void));
-int hash __P((char *));
-void initialize __P((char *));
+int hash __P((const char *));
+void initialize __P((const char *));
 void install __P((struct wlist *));
 int jump __P((void));
 void kiss __P((void));
 int land __P((void));
 int launch __P((void));
 void light __P((void));
-void live __P((void));
+void live __P((void)) __attribute__((__noreturn__));
 void love __P((void));
 int move __P((int, int));
 void moveenemy __P((int));
@@ -341,33 +343,34 @@ void murder __P((void));
 void news __P((void));
 void newway __P((int));
 void notarget __P((void));
+void open_score_file __P((void));
 void parse __P((void));
 void post __P((char));
 void printobjs __P((void));
 int put __P((void));
 int puton __P((void));
 void ravage __P((void));
-void restore __P((char *));
+void restore __P((const char *, size_t));
 int ride __P((void));
-void save __P((char *));
+void save __P((const char *, size_t));
 void screen __P((void));
 int shoot __P((void));
 void succumb __P((int));
 int take __P((unsigned int[]));
 int takeoff __P((void));
 void target __P((void));
-int throw __P((char *));
-int ucard __P((unsigned int *));
+int throw __P((const char *));
+int ucard __P((const unsigned int *));
 int use __P((void));
 int visual __P((void));
 int wearit __P((void));
 void whichway __P((struct room));
-int wizard __P((char *));
+int wizard __P((const char *));
 void wordinit __P((void));
 void writedes __P((void));
 int zzz __P((void));
-char   *getcom __P((char *, int, char *, char *));
+char   *getcom __P((char *, int, const char *, const char *));
 char   *getword __P((char *, char *, int));
-char   *rate __P((void));
-char   *truedirec __P((int, char));
-struct wlist *lookup __P((char *));
+const char   *rate __P((void));
+const char   *truedirec __P((int, char));
+struct wlist *lookup __P((const char *));
