@@ -1,4 +1,4 @@
-/*	$NetBSD: fortune.c,v 1.12 1998/02/04 10:16:20 christos Exp $	*/
+/*	$NetBSD: fortune.c,v 1.14 1998/09/13 15:27:28 hubertf Exp $	*/
 
 /*-
  * Copyright (c) 1986, 1993
@@ -46,7 +46,7 @@ __COPYRIGHT("@(#) Copyright (c) 1986, 1993\n\
 #if 0
 static char sccsid[] = "@(#)fortune.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: fortune.c,v 1.12 1998/02/04 10:16:20 christos Exp $");
+__RCSID("$NetBSD: fortune.c,v 1.14 1998/09/13 15:27:28 hubertf Exp $");
 #endif
 #endif /* not lint */
 
@@ -164,7 +164,7 @@ void	 print_file_list __P((void));
 void	 print_list __P((FILEDESC *, int));
 void	 sum_noprobs __P((FILEDESC *));
 void	 sum_tbl __P((STRFILE *, STRFILE *));
-void	 usage __P((void));
+void	 usage __P((void)) __attribute__((__noreturn__));
 void	 zero_tbl __P((STRFILE *));
 
 #ifndef	NO_REGEX
@@ -216,6 +216,9 @@ main(ac, av)
 	int	fd;
 #endif	/* OK_TO_WRITE_DISK */
 
+	/* Revoke setgid privileges */
+	setregid(getgid(), getgid());
+
 	getargs(ac, av);
 
 #ifndef NO_REGEX
@@ -896,8 +899,7 @@ init_prob()
 			num_noprob++;
 			if (Equal_probs)
 				last = fp;
-		}
-		else
+		} else
 			percent += fp->percent;
 	DPRINTF(1, (stderr, "summing probabilities:%d%% with %d NO_PROB's",
 		    percent, num_noprob));
@@ -923,8 +925,7 @@ init_prob()
 			last->percent = percent;
 			DPRINTF(1, (stderr, ", residual = %d%%", percent));
 		}
-	}
-	else {
+	} else {
 		DPRINTF(1, (stderr,
 			    ", %d%% distributed over remaining fortunes\n",
 			    percent));
@@ -994,7 +995,7 @@ get_fort()
 	get_pos(fp);
 	open_dat(fp);
 	(void) lseek(fp->datfd,
-		     (off_t) (sizeof fp->tbl + fp->pos * sizeof Seekpts[0]), 0);
+		     (off_t) (sizeof fp->tbl + fp->pos * sizeof Seekpts[0]), SEEK_SET);
 	read(fp->datfd, Seekpts, sizeof Seekpts);
 	Seekpts[0] = ntohl(Seekpts[0]);
 	Seekpts[1] = ntohl(Seekpts[1]);
