@@ -71,7 +71,7 @@ char	*prog;			/* name of program */
 FILE	*debugfp;		/* file for debug output */
 FILE	*inputfp;		/* file for debug input */
 
-char	pdir[4]		= "-\\|/";
+const char	pdir[4]		= "-\\|/";
 char	fmtbuf[128];
 
 struct	spotstr	board[BAREA];		/* info for board */
@@ -81,7 +81,7 @@ u_char	overlap[FAREA * FAREA];		/* true if frame [a][b] overlap */
 short	intersect[FAREA * FAREA];	/* frame [a][b] intersection */
 int	movelog[BSZ * BSZ];		/* log of all the moves */
 int	movenum;			/* current move number */
-char	*plyr[2];			/* who's who */
+const char	*plyr[2];			/* who's who */
 
 int	main __P((int, char *[]));
 
@@ -93,11 +93,14 @@ main(argc, argv)
 	char buf[128];
 	int color, curmove, i, ch;
 	int input[2];
-	static char *fmt[2] = {
+	static const char *const fmt[2] = {
 		"%3d %-6s",
 		"%3d        %-6s"
 	};
 
+	/* revoke setgid privileges */
+	setregid(getgid(), getgid());
+
 	color = curmove = 0;
 
 	prog = strrchr(argv[0], '/');
@@ -259,7 +262,7 @@ again:
 					ask("save file name? ");
 					(void)getline(buf, sizeof(buf));
 					if ((fp = fopen(buf, "w")) == NULL) {
-						log("cannot create save file");
+						glog("cannot create save file");
 						goto getinput;
 					}
 					for (i = 0; i < movenum - 1; i++)
@@ -270,7 +273,7 @@ again:
 				}
 				if (curmove != RESIGN &&
 				    board[curmove].s_occ != EMPTY) {
-					log("Illegal move");
+					glog("Illegal move");
 					goto getinput;
 				}
 			}
@@ -282,7 +285,7 @@ again:
 		}
 		if (interactive) {
 			sprintf(fmtbuf, fmt[color], movenum, stoc(curmove));
-			log(fmtbuf);
+			glog(fmtbuf);
 		}
 		if ((i = makemove(color, curmove)) != MOVEOK)
 			break;
@@ -319,7 +322,7 @@ again:
 				ask("save file name? ");
 				(void)getline(buf, sizeof(buf));
 				if ((fp = fopen(buf, "w")) == NULL) {
-					log("cannot create save file");
+					glog("cannot create save file");
 					goto replay;
 				}
 				for (i = 0; i < movenum - 1; i++)
@@ -497,7 +500,7 @@ syntax:
  */
 void
 dlog(str)
-	char *str;
+	const char *str;
 {
 
 	if (debugfp)
@@ -509,8 +512,8 @@ dlog(str)
 }
 
 void
-log(str)
-	char *str;
+glog(str)
+	const char *str;
 {
 
 	if (debugfp)
@@ -543,7 +546,7 @@ quitsig(dummy)
  */
 void
 panic(str)
-	char *str;
+	const char *str;
 {
 	fprintf(stderr, "%s: %s\n", prog, str);
 	fputs("resign\n", stdout);
