@@ -175,8 +175,8 @@ pickmove(us)
  */
 int
 better(sp, sp1, us)
-	struct spotstr *sp;
-	struct spotstr *sp1;
+	const struct spotstr *sp;
+	const struct spotstr *sp1;
 	int us;
 {
 	int them, s, s1;
@@ -483,6 +483,8 @@ makecombo2(ocbp, osp, off, s)
 		/* make a new combo! */
 		ncbp = (struct combostr *)malloc(sizeof(struct combostr) +
 		    2 * sizeof(struct combostr *));
+		if (ncbp == NULL)
+		    panic("Out of memory!");
 		scbpp = (struct combostr **)(ncbp + 1);
 		fcbp = fsp->s_frame[r];
 		if (ocbp < fcbp) {
@@ -722,6 +724,8 @@ makecombo(ocbp, osp, off, s)
 	    /* make a new combo! */
 	    ncbp = (struct combostr *)malloc(sizeof(struct combostr) +
 		(cbp->c_nframes + 1) * sizeof(struct combostr *));
+	    if (ncbp == NULL)
+		panic("Out of memory!");
 	    scbpp = (struct combostr **)(ncbp + 1);
 	    if (sortcombo(scbpp, (struct combostr **)(cbp + 1), ocbp)) {
 		free(ncbp);
@@ -922,6 +926,8 @@ makeempty(ocbp)
 
 			/* add the combo to the list of empty spots */
 			nep = (struct elist *)malloc(sizeof(struct elist));
+			if (nep == NULL)
+				panic("Out of memory!");
 			nep->e_combo = ocbp;
 			nep->e_off = s;
 			nep->e_frameindex = i;
