@@ -1,4 +1,4 @@
-/*	$NetBSD: hunt.c,v 1.4 1997/10/20 00:37:14 lukem Exp $	*/
+/*	$NetBSD: hunt.c,v 1.8 1998/09/13 15:27:28 hubertf Exp $	*/
 /*
  *  Hunt
  *  Copyright (c) 1985 Conrad C. Huang, Gregory S. Couch, Kenneth C.R.C. Arnold
@@ -7,7 +7,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__RCSID("$NetBSD: hunt.c,v 1.4 1997/10/20 00:37:14 lukem Exp $");
+__RCSID("$NetBSD: hunt.c,v 1.8 1998/09/13 15:27:28 hubertf Exp $");
 #endif /* not lint */
 
 # include	<sys/stat.h>
@@ -23,6 +23,7 @@ __RCSID("$NetBSD: hunt.c,v 1.4 1997/10/20 00:37:14 lukem Exp $");
 # include	<termios.h>
 static struct termios saved_tty;
 # endif
+# include	<sys/param.h>
 # include	<unistd.h>
 
 # include	"hunt.h"
@@ -87,7 +88,7 @@ extern int	cur_row, cur_col;
 void	dump_scores __P((SOCKET));
 long	env_init __P((long));
 void	fill_in_blanks __P((void));
-void	leave __P((int, char *));
+void	leave __P((int, const char *)) __attribute__((__noreturn__));
 int	main __P((int, char *[]));
 # ifdef INTERNET
 SOCKET *list_drivers __P((void));
@@ -104,12 +105,14 @@ main(ac, av)
 {
 	char		*term;
 	int		c;
-	extern int	errno;
 	extern int	Otto_mode;
 	extern int	optind;
 	extern char	*optarg;
 	long		enter_status;
 
+	/* Revoke setgid privileges */
+	setregid(getgid(), getgid());
+
 	enter_status = env_init((long) Q_CLOAK);
 	while ((c = getopt(ac, av, "Sbcfh:l:mn:op:qst:w:")) != -1) {
 		switch (c) {
@@ -373,6 +376,8 @@ broadcast_vec(s, vector)
 	vec_cnt = 0;
 	n = ifc.ifc_len / sizeof (struct ifreq);
 	*vector = (struct sockaddr *) malloc(n * sizeof (struct sockaddr));
+	if (*vector == NULL)
+		leave(1, "Out of memory!");
 	for (ifr = ifc.ifc_req; n != 0; n--, ifr++)
 		if (ioctl(s, SIOCGIFBRDADDR, ifr) >= 0)
 			memcpy(&(*vector)[vec_cnt++], &ifr->ifr_addr,
@@ -390,11 +395,10 @@ list_drivers()
 	static SOCKET		test;
 	int			test_socket;
 	int			namelen;
-	char			local_name[256];
+	char			local_name[MAXHOSTNAMELEN + 1];
 	static int		initial = TRUE;
 	static struct in_addr	local_address;
 	struct hostent		*hp;
-	extern int		errno;
 # ifdef BROADCAST
 	static	int		brdc;
 	static	SOCKET		*brdv;
@@ -416,6 +420,7 @@ list_drivers()
 			leave(1, "Sorry, I have no name.");
 			/* NOTREACHED */
 		}
+		local_name[sizeof(local_name) - 1] = '\0';
 		if ((hp = gethostbyname(local_name)) == NULL) {
 			leave(1, "Can't find myself.");
 			/* NOTREACHED */
@@ -424,6 +429,8 @@ list_drivers()
 
 		listmax = 20;
 		listv = (SOCKET *) malloc(listmax * sizeof (SOCKET));
+		if (listv == NULL)
+			leave(1, "Out of memory!");
 	} else if (Sock_host != NULL)
 		return listv;		/* address already valid */
 
@@ -510,6 +517,8 @@ get_response:
 			listmax += 20;
 			listv = (SOCKET *) realloc((char *) listv,
 						listmax * sizeof(SOCKET));
+			if (listv == NULL)
+				leave(1, "Out of memory!");
 		}
 
 		FD_ZERO(&mask);
@@ -854,7 +863,7 @@ intr(dummy)
 void
 leave(eval, mesg)
 	int	eval;
-	char	*mesg;
+	const char	*mesg;
 {
 	if (in_visual) {
 # ifdef USE_CURSES
