@@ -252,14 +252,8 @@ init()
 # endif
 
 # ifndef DEBUG
-# ifdef TIOCNOTTY
-	(void) ioctl(fileno(stdout), TIOCNOTTY, NULL);
-# endif
-#ifdef __linux__
-	setpgid(getpid(), getpid());
-#else
-	(void) setpgrp(getpid(), getpid());
-#endif
+	if (setsid() == -1)
+		err(1, "setsid");
 	(void) signal(SIGHUP, SIG_IGN);
 	(void) signal(SIGINT, SIG_IGN);
 	(void) signal(SIGQUIT, SIG_IGN);
@@ -462,7 +456,7 @@ checkdam(ouch, gotcha, credit, amt, shot_type)
 	int	amt;
 	char	shot_type;
 {
-	char	*cp;
+	const char	*cp;
 
 	if (ouch->p_death[0] != '\0')
 		return;
