@@ -1,4 +1,4 @@
-/*	$NetBSD: monop.c,v 1.4 1997/10/12 17:45:16 christos Exp $	*/
+/*	$NetBSD: monop.c,v 1.5 1998/09/11 13:54:08 hubertf Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -43,7 +43,7 @@ __COPYRIGHT("@(#) Copyright (c) 1980, 1993\n\
 #if 0
 static char sccsid[] = "@(#)monop.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: monop.c,v 1.4 1997/10/12 17:45:16 christos Exp $");
+__RCSID("$NetBSD: monop.c,v 1.5 1998/09/11 13:54:08 hubertf Exp $");
 #endif
 #endif /* not lint */
 
@@ -67,6 +67,8 @@ main(ac, av)
 int		ac;
 char	*av[]; {
 
+	/* Revoke setgid privileges */
+	setregid(getgid(), getgid());
 
 	srand(getpid());
 	if (ac > 1) {
