@@ -1,4 +1,4 @@
-/*	$NetBSD: quiz.c,v 1.12 1997/09/20 14:28:18 lukem Exp $	*/
+/*	$NetBSD: quiz.c,v 1.13 1998/09/13 15:27:29 hubertf Exp $	*/
 
 /*-
  * Copyright (c) 1991, 1993
@@ -47,7 +47,7 @@ __COPYRIGHT("@(#) Copyright (c) 1991, 1993\n\
 #if 0
 static char sccsid[] = "@(#)quiz.c	8.3 (Berkeley) 5/4/95";
 #else
-__RCSID("$NetBSD: quiz.c,v 1.12 1997/09/20 14:28:18 lukem Exp $");
+__RCSID("$NetBSD: quiz.c,v 1.13 1998/09/13 15:27:29 hubertf Exp $");
 #endif
 #endif /* not lint */
 
@@ -78,7 +78,7 @@ char	*next_cat __P((char *));
 void	 quiz __P((void));
 void	 score __P((u_int, u_int, u_int));
 void	 show_index __P((void));
-void	 usage __P((void));
+void	 usage __P((void)) __attribute__((__noreturn__));
 
 int
 main(argc, argv)
@@ -88,6 +88,9 @@ main(argc, argv)
 	int ch;
 	char *indexfile;
 
+	/* Revoke setgid privileges */
+	setregid(getgid(), getgid());
+
 	indexfile = _PATH_QUIZIDX;
 	while ((ch = getopt(argc, argv, "i:t")) != -1)
 		switch(ch) {
@@ -166,8 +169,15 @@ show_index()
 	QE *qp;
 	char *p, *s;
 	FILE *pf;
+	char *pager;
 
-	if ((pf = popen(_PATH_PAGER, "w")) == NULL)
+	if (!isatty(1))
+		pager = "cat";
+	else {
+		if (!(pager = getenv("PAGER")) || (*pager == 0))
+			pager = _PATH_PAGER;
+	}
+	if ((pf = popen(pager, "w")) == NULL)
 		err(1, "%s", _PATH_PAGER);
 	(void)fprintf(pf, "Subjects:\n\n");
 	for (qp = qlist.q_next; qp; qp = qp->q_next) {
