@@ -1,4 +1,4 @@
-/*	$NetBSD: sync.c,v 1.7 1997/10/13 21:04:40 christos Exp $	*/
+/*	$NetBSD: sync.c,v 1.10 1998/09/11 14:15:46 hubertf Exp $	*/
 
 /*
  * Copyright (c) 1983, 1993
@@ -38,7 +38,7 @@
 #if 0
 static char sccsid[] = "@(#)sync.c	8.2 (Berkeley) 4/28/95";
 #else
-__RCSID("$NetBSD: sync.c,v 1.7 1997/10/13 21:04:40 christos Exp $");
+__RCSID("$NetBSD: sync.c,v 1.10 1998/09/11 14:15:46 hubertf Exp $");
 #endif
 #endif /* not lint */
 
@@ -56,6 +56,7 @@ __RCSID("$NetBSD: sync.c,v 1.7 1997/10/13 21:04:40 christos Exp $");
 #include <sys/stat.h>
 #include <time.h>
 #include "extern.h"
+#include "pathnames.h"
 
 #define BUFSIZE 4096
 
@@ -65,8 +66,6 @@ static char sync_lock[25];
 static char sync_file[25];
 static long sync_seek;
 static FILE *sync_fp;
-#define SF "/tmp/#sailsink.%d"
-#define LF "/tmp/#saillock.%d"
 
 void
 fmtship(buf, len, fmt, ship)
@@ -150,6 +149,7 @@ makemsg(va_alias)
 	va_end(ap);
 	Write(W_SIGNAL, from, 1, (long)message, 0, 0, 0);
 }
+
 int
 sync_exists(game)
 	int game;
@@ -158,32 +158,41 @@ sync_exists(game)
 	struct stat s;
 	time_t t;
 
-	(void) sprintf(buf, SF, game);
+	(void) sprintf(buf, _PATH_SYNC, game);
 	(void) time(&t);
-	if (stat(buf, &s) < 0)
+	setegid(egid);
+	if (stat(buf, &s) < 0) {
+		setegid(gid);
 		return 0;
+	}
 	if (s.st_mtime < t - 60*60*2) {		/* 2 hours */
 		(void) unlink(buf);
-		(void) sprintf(buf, LF, game);
+		(void) sprintf(buf, _PATH_LOCK, game);
 		(void) unlink(buf);
+		setegid(gid);
 		return 0;
-	} else
+	} else {
+		setegid(gid);
 		return 1;
+	}
 }
 
 int
 sync_open()
 {
+	struct stat tmp;
 	if (sync_fp != NULL)
 		(void) fclose(sync_fp);
-	(void) sprintf(sync_lock, LF, game);
-	(void) sprintf(sync_file, SF, game);
-	if (access(sync_file, 0) < 0) {
-		int omask = umask(issetuid ? 077 : 011);
+	(void) sprintf(sync_lock, _PATH_LOCK, game);
+	(void) sprintf(sync_file, _PATH_SYNC, game);
+	setegid(egid);
+	if (stat(sync_file, &tmp) < 0) {
+		mode_t omask = umask(002);
 		sync_fp = fopen(sync_file, "w+");
 		(void) umask(omask);
 	} else
 		sync_fp = fopen(sync_file, "r+");
+	setegid(gid);
 	if (sync_fp == NULL)
 		return -1;
 	sync_seek = 0;
@@ -196,8 +205,11 @@ sync_close(remove)
 {
 	if (sync_fp != 0)
 		(void) fclose(sync_fp);
-	if (remove)
+	if (remove) {
+		setegid(egid);
 		(void) unlink(sync_file);
+		setegid(gid);
+	}
 }
 
 void
@@ -241,8 +253,12 @@ Sync()
 		if (errno != EWOULDBLOCK)
 			return -1;
 #else
-		if (link(sync_file, sync_lock) >= 0)
+		setegid(egid);
+		if (link(sync_file, sync_lock) >= 0) {
+			setegid(gid);
 			break;
+		}
+		setegid(gid);
 		if (errno != EEXIST)
 			return -1;
 #endif
@@ -304,7 +320,9 @@ out:
 #ifdef LOCK_EX
 	(void) flock(fileno(sync_fp), LOCK_UN);
 #else
+	setegid(egid);
 	(void) unlink(sync_lock);
+	setegid(gid);
 #endif
 	(void) signal(SIGHUP, sighup);
 	(void) signal(SIGINT, sigint);
