@@ -70,10 +70,6 @@ __RCSID("$NetBSD: snake.c,v 1.9 1997/10/12 01:49:28 lukem Exp $");
 #include "snake.h"
 #include "pathnames.h"
 
-#ifndef CTRL
-#define CTRL(X) ((X) & 037)
-#endif
-
 #define PENALTY  10		/* % penalty for invoking spacewarp	 */
 
 #define EOT	'\004'
@@ -109,6 +105,9 @@ int     repeat = 1;
 time_t  tv;
 char   *tn;
 
+int rawscores;
+FILE *logfile;
+
 int main __P((int, char **));
 
 int
@@ -120,6 +119,19 @@ main(argc, argv)
 	extern int optind;
 	int     ch, i;
 
+	/* Open score files then revoke setgid privileges */
+	rawscores = open(_PATH_RAWSCORES, O_RDWR|O_CREAT, 0664);
+	if (rawscores < 0) {
+		warn("open %s", _PATH_RAWSCORES);
+		sleep(2);
+	}
+	logfile = fopen(_PATH_LOGFILE, "a");
+	if (logfile == NULL) {
+		warn("fopen %s", _PATH_LOGFILE);
+		sleep(2);
+	}
+	setregid(getgid(), getgid());
+
 	(void) time(&tv);
 	srandom((int) tv);
 
@@ -496,7 +508,6 @@ post(iscore, flag)
 	int     iscore, flag;
 {
 	short   score = iscore;
-	int     rawscores;
 	short   uid;
 	short   oldbest = 0;
 	short   allbwho = 0, allbscore = 0;
@@ -509,22 +520,21 @@ post(iscore, flag)
 		pr("No saved scores for uid %d.\n", uid);
 		return (1);
 	}
-	if ((rawscores = open(_PATH_RAWSCORES, O_RDWR | O_CREAT, 0644)) < 0) {
-		pr("No score file %s: %s.\n", _PATH_RAWSCORES,
-		    strerror(errno));
+	if (rawscores < 0) {
+		/* Error reported earlier */
 		return (1);
 	}
 	/* Figure out what happened in the past */
 	read(rawscores, &allbscore, sizeof(short));
 	read(rawscores, &allbwho, sizeof(short));
-	lseek(rawscores, uid * sizeof(short), 0);
+	lseek(rawscores, uid * sizeof(short), SEEK_SET);
 	read(rawscores, &oldbest, sizeof(short));
 	if (!flag)
 		return (score > oldbest ? 1 : 0);
 
 	/* Update this jokers best */
 	if (score > oldbest) {
-		lseek(rawscores, uid * sizeof(short), 0);
+		lseek(rawscores, uid * sizeof(short), SEEK_SET);
 		write(rawscores, &score, sizeof(short));
 		pr("You bettered your previous best of $%d\n", oldbest);
 	} else
@@ -533,7 +543,7 @@ post(iscore, flag)
 	/* See if we have a new champ */
 	p = getpwuid(allbwho);
 	if (p == NULL || score > allbscore) {
-		lseek(rawscores, 0, 0);
+		lseek(rawscores, 0, SEEK_SET);
 		write(rawscores, &score, sizeof(short));
 		write(rawscores, &uid, sizeof(short));
 		if (allbwho)
@@ -543,7 +553,7 @@ post(iscore, flag)
 			pr("You set a new record!\n");
 	} else
 		pr("The highest is %s with $%d\n", p->pw_name, allbscore);
-	close(rawscores);
+	lseek(rawscores, 0, SEEK_SET);
 	return (1);
 }
 
@@ -930,7 +940,7 @@ suspend()
 	ll();
 	cook();
 	kill(getpid(), SIGTSTP);
-	raw();
+	my_raw();
 	setup();
 	winnings(cashvalue);
 }
@@ -946,13 +956,12 @@ void
 logit(msg)
 	const char   *msg;
 {
-	FILE   *logfile;
 	time_t  t;
 
-	if ((logfile = fopen(_PATH_LOGFILE, "a")) != NULL) {
+	if (logfile != NULL) {
 		time(&t);
 		fprintf(logfile, "%s $%d %dx%d %s %s",
 		    getlogin(), cashvalue, lcnt, ccnt, msg, ctime(&t));
-		fclose(logfile);
+		fflush(logfile);
 	}
 }
